==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/enums/VirtualMachineSizeTypes.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The size of the virtual machine.
 */
public enum class VirtualMachineSizeTypes(
    public val javaValue: com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes> {
    Unknown(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Unknown),
    Standard_D1_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D1_v2),
    Standard_D2_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D2_v2),
    Standard_D3_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D3_v2),
    Standard_D4_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D4_v2),
    Standard_D5_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D5_v2),
    Standard_D11_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D11_v2),
    Standard_D12_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D12_v2),
    Standard_D13_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D13_v2),
    Standard_DS1_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS1_v2),
    Standard_DS2_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS2_v2),
    Standard_DS3_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS3_v2),
    Standard_DS4_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS4_v2),
    Standard_DS5_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS5_v2),
    Standard_DS11_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS11_v2),
    Standard_DS12_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS12_v2),
    Standard_DS13_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS13_v2),
    Standard_F1(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F1),
    Standard_F2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F2),
    Standard_F4(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F4),
    Standard_F8(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F8),
    Standard_F16(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F16),
    Standard_F1s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F1s),
    Standard_F2s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F2s),
    Standard_F4s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F4s),
    Standard_F8s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F8s),
    Standard_F16s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F16s),
    ;

    override fun toJava(): com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes):
            VirtualMachineSizeTypes =
            VirtualMachineSizeTypes.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/enums/VirtualMachineSizeTypes.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The size of the virtual machine.
 */
public enum class VirtualMachineSizeTypes(
    public val javaValue: com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes> {
    Unknown(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Unknown),
    Standard_D1_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D1_v2),
    Standard_D2_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D2_v2),
    Standard_D3_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D3_v2),
    Standard_D4_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D4_v2),
    Standard_D5_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D5_v2),
    Standard_D11_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D11_v2),
    Standard_D12_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D12_v2),
    Standard_D13_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_D13_v2),
    Standard_DS1_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS1_v2),
    Standard_DS2_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS2_v2),
    Standard_DS3_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS3_v2),
    Standard_DS4_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS4_v2),
    Standard_DS5_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS5_v2),
    Standard_DS11_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS11_v2),
    Standard_DS12_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS12_v2),
    Standard_DS13_v2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_DS13_v2),
    Standard_F1(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F1),
    Standard_F2(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F2),
    Standard_F4(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F4),
    Standard_F8(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F8),
    Standard_F16(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F16),
    Standard_F1s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F1s),
    Standard_F2s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F2s),
    Standard_F4s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F4s),
    Standard_F8s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F8s),
    Standard_F16s(com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes.Standard_F16s),
    ;

    override fun toJava(): com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.hybridnetwork.enums.VirtualMachineSizeTypes): VirtualMachineSizeTypes =
            VirtualMachineSizeTypes.values().first { it.javaValue == javaType }
    }
}
